@@ -21,7 +21,6 @@ from mdpo.po import (
     po_escaped_string,
     remove_not_found_entries,
 )
-from mdpo.polib import *  # noqa
 from mdpo.text import min_not_max_chars_in_a_row
 
 
@@ -48,6 +47,7 @@ class Md2Po:
         'location',
         '_current_top_level_block_number',
         '_current_top_level_block_type',
+        '_current_markdown_filepath',
 
         '_current_msgid',
         '_current_tcomment',
@@ -138,6 +138,7 @@ class Md2Po:
         self.location = kwargs.get('location', True)
         self._current_top_level_block_number = 0
         self._current_top_level_block_type = None
+        self._current_markdown_filepath = None
 
         self.extensions = kwargs.get(
             'extensions',
@@ -345,18 +346,26 @@ class Md2Po:
         if 'metadata' in kwargs:
             self.metadata.update(kwargs['metadata'])
 
-    def _save_msgid(self, msgid, tcomment=None, msgctxt=None):
+    def _save_msgid(
+        self,
+        msgid,
+        msgstr='',
+        tcomment=None,
+        msgctxt=None,
+        fuzzy=False,
+    ):
         if msgid in self.ignore_msgids:
             return
         entry = polib.POEntry(
             msgid=msgid,
-            msgstr=self.msgstr,
+            msgstr=msgstr,
             comment=tcomment,
             msgctxt=msgctxt,
+            flags=[] if not fuzzy else ['fuzzy'],
         )
 
         occurrence = None
-        if self.location and self.po_filepath:
+        if self.location and self._current_markdown_filepath:
             # here could happen a KeyError if someone has aborted an ,
             # enter event, in which case we do not have access to the
             # block type because ``self._current_top_level_block_type is None``
@@ -373,7 +382,7 @@ class Md2Po:
             #       accordingly
 
             occurrence = (
-                self.po_filepath,
+                self._current_markdown_filepath,
                 (
                     f'block {self._current_top_level_block_number}'
                     f' ({current_block_name})'
@@ -397,9 +406,9 @@ class Md2Po:
                 entry.flags.append('fuzzy')
         if entry not in self.pofile:
             self.pofile.append(entry)
-            self.found_entries.append(entry)
+        self.found_entries.append(entry)
 
-    def _save_current_msgid(self):
+    def _save_current_msgid(self, msgstr='', fuzzy=False):
         # raise 'msgid' event
         try:
             pre_event = self.events['msgid']
@@ -414,16 +423,19 @@ class Md2Po:
                     self._enable_next_line:
                 self._save_msgid(
                     self._current_msgid,
+                    msgstr=msgstr or self.msgstr,
                     tcomment=self._current_tcomment,
                     msgctxt=self._current_msgctxt,
+                    fuzzy=fuzzy,
                 )
             else:
                 self.disabled_entries.append(
                     polib.POEntry(
                         msgid=self._current_msgid,
-                        msgstr=self.msgstr,
+                        msgstr=msgstr or self.msgstr,
                         comment=self._current_tcomment,
                         msgctxt=self._current_msgctxt,
+                        fuzzy=fuzzy,
                     ),
                 )
         self._disable_next_line = False
@@ -810,13 +822,22 @@ class Md2Po:
             self._disable_next_line = False
             self._disable = False
 
+            # 'link_reference' event
+            pre_event = self.events.get('link_reference')
+
             for target, href, title in self._link_references:
+                if pre_event and pre_event(self, target, href, title) is False:
+                    continue
+
                 self._current_msgid = '[{}]:{}{}'.format(
                     target,
                     f' {href}' if href else '',
                     f' "{title}"' if title else '',
                 )
-                self._save_current_msgid()
+                self._save_current_msgid(
+                    msgstr=self._current_msgid,
+                    fuzzy=True,
+                )
 
     def extract(
         self,
@@ -865,6 +886,7 @@ class Md2Po:
             for filepath in self.filepaths:
                 with open(filepath, encoding=md_encoding) as f:
                     self.content = f.read()
+                self._current_markdown_filepath = filepath
                 _parse(self.content)
 
                 self._disable_next_line = False
@@ -995,6 +1017,8 @@ def markdown_to_pofile(
             * ``text``: Executed when the parsing of text starts ends.
             * ``command``: Executed when a mdpo HTML command is found.
             * ``msgid``: Executed when a msgid is going to be stored.
+            * ``link_reference``: Executed when a link reference is going to be
+              stored.
 
     Examples:
         >>> content = 'Some text with `inline code`'
