@@ -9,7 +9,6 @@ from mdpo.cli import (
     add_common_cli_first_arguments,
     add_common_cli_latest_arguments,
     parse_command_aliases_cli_arguments,
-    parse_list_cli_argument,
     parse_metadata_cli_arguments,
 )
 from mdpo.md2po import markdown_to_pofile
@@ -32,10 +31,10 @@ def build_parser():
              ' If not provided, will be read from STDIN.',
     )
     parser.add_argument(
-        '-i', '--ignore', dest='ignore', default=[],
-        help='Filepaths to ignore when \'GLOB_OR_CONTENT\' argument'
-             ' is a glob, as a list of comma separated values.',
-        metavar='PATH_1,PATH_2...',
+        '-i', '--ignore', dest='ignore', default=[], action='append',
+        help='Filepath to ignore when \'GLOB_OR_CONTENT\' argument'
+             ' is a glob. This argument can be passed multiple times.',
+        metavar='PATH',
     )
     parser.add_argument(
         '-po', '--po-filepath', dest='po_filepath',
@@ -97,14 +96,15 @@ def build_parser():
              "--no-location'.",
     )
     parser.add_argument(
-        '-x', '--extensions', dest='extensions',
-        default=','.join(
-            DEFAULT_MD4C_GENERIC_PARSER_EXTENSIONS,
-        ),
-        help='md4c extensions used to parse markdown content, separated by'
-             ' \',\' and formatted as pymd4c extension keyword arguments.'
-             ' You can see all available at https://github.com/dominickpastore'
-             '/pymd4c#parser-option-flags',
+        '-x', '--extension', dest='extensions', action='append',
+        default=None,
+        help='md4c extension used to parse markdown content formatted as'
+             ' pymd4c extension keyword arguments. This argument can be passed'
+             ' multiple times. If is not passed, next extensions are used:'
+             f' {", ".join(DEFAULT_MD4C_GENERIC_PARSER_EXTENSIONS)}.'
+             ' You can see all available at'
+             ' https://github.com/dominickpastore/pymd4c#parser-option-flags',
+        metavar='<EXTENSION>',
     )
     parser.add_argument(
         '--po-encoding', dest='po_encoding', default=None,
@@ -158,9 +158,10 @@ def parse_options(args=[]):
         opts.glob_or_content = sys.stdin.read().strip('\n')
     elif isinstance(opts.glob_or_content, list):
         opts.glob_or_content = opts.glob_or_content[0]
-    if opts.ignore:
-        opts.ignore = parse_list_cli_argument(opts.ignore)
-    opts.extensions = opts.extensions.split(',')
+
+    if opts.extensions is None:
+        opts.extensions = DEFAULT_MD4C_GENERIC_PARSER_EXTENSIONS
+
     if opts.ignore_msgids is not None:
         with open(opts.ignore_msgids) as f:
             opts.ignore_msgids = f.read().splitlines()
@@ -204,7 +205,7 @@ def run(args=[]):
     pofile = markdown_to_pofile(opts.glob_or_content, **kwargs)
 
     if not opts.quiet:
-        sys.stdout.write('%s\n' % pofile.__unicode__())
+        sys.stdout.write(pofile.__unicode__() + '\n')
 
     return (pofile, 0)
 
