@@ -23,7 +23,6 @@ from mdpo.po import (
     po_escaped_string,
     pofiles_to_unique_translations_dicts,
 )
-from mdpo.polib import *  # noqa
 from mdpo.text import (
     min_not_max_chars_in_a_row,
     removesuffix,
@@ -742,10 +741,7 @@ class Po2Md:
             self._disable_next_line = False
             self._disable = False
 
-            try:
-                pre_event = self.events['link_reference']
-            except KeyError:
-                pre_event = None
+            pre_event = self.events.get('link_reference')
 
             _references_added = []  # don't repeat references
             for target, href, title in self._link_references:
